.. _ansible_community_guide:

***********************
Ansible Community Guide
***********************

Welcome to the Ansible Community Guide!

The purpose of this guide is to teach you everything you need to know about being a contributing member of the Ansible community.

To get started, please read and understand the :ref:`code_of_conduct`, and then select one of the following topics.


.. toctree::
   :maxdepth: 2

   code_of_conduct
   development_process
   reporting_bugs_and_features
   how_can_I_help
   maintainers
   release_managers
   communication
   other_tools_and_programs
   



